"""Components used to encode the input data."""
from evalml.pipelines.components.transformers.encoders.onehot_encoder import (
    OneHotEncoder,
)
from evalml.pipelines.components.transformers.encoders.target_encoder import (
    TargetEncoder,
)
from evalml.pipelines.components.transformers.encoders.label_encoder import LabelEncoder
from evalml.pipelines.components.transformers.encoders.ordinal_encoder import (
    OrdinalEncoder,
)
